@@ -28,7 +28,7 @@ class GSPeerConnectionWatcher:
     async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None):
         self = GSPeerConnectionWatcher()
         rtconfiList = []
-        if self.gsdbs.credentials["stunEnable"]:
+        if self.gsdbs.credentials["stunenable"]:
             rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
         if self.gsdbs.credentials["turnenable"]:
             rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
@@ -57,7 +57,10 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def offer(id, description):
-            pc = RTCPeerConnection()
+            if len(rtconfiList) > 0:
+                pc = RTCPeerConnection(configuration=RTCConfiguration(rtconfiList))
+            else:
+                pc = RTCPeerConnection()
 
             @self.peerConnections.on("datachannel")
             def on_datachannel(channel):
